BuffInt class

A 32-bit signed integer between -2147483648 and 2147483647.

Inheritance

Constructors

BuffInt()

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String
得到该节点的key
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → int
得到这个buff的类型
no setteroverride
value ↔ dynamic
得到该节点的实例或引用
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited