BuffConverterBase class

Buff与值的转换器基类

Constructors

BuffConverterBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

boolFromBuff(String key, IBuffInfo buff) → bool
boolToBuff(bool target, String key) → BuffBoolean
byteFromBuff(String key, IBuffInfo buff) → int
bytesFromBuff(String key, IBuffInfo buff) → ByteArray
bytesToBuff(ByteArray target, String key) → BuffBytes
byteToBuff(int target, String key) → BuffByte
doubleFromBuff(String key, IBuffInfo buff) → double
doubleToBuff(double target, String key) → BuffDouble
floatFromBuff(String key, IBuffInfo buff) → double
floatToBuff(double target, String key) → BuffFloat
int64FromBuff(String key, IBuffInfo buff) → int
int64ToBuff(int target, String key) → BuffInt64
intFromBuff(String key, IBuffInfo buff) → int
intToBuff(int target, String key) → BuffInt
longstringFromBuff(String key, IBuffInfo buff) → String
longstringToBuff(String target, String key) → BuffLongString
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shortFromBuff(String key, IBuffInfo buff) → int
shortToBuff(int target, String key) → BuffShort
stringFromBuff(String key, IBuffInfo buff) → String
stringToBuff(String target, String key) → BuffString
toString() → String
A string representation of this object.
inherited
ubyteFromBuff(String key, IBuffInfo buff) → int
ubyteToBuff(int target, String key) → BuffUByte
uintFromBuff(String key, IBuffInfo buff) → int
uintToBuff(int target, String key) → BuffUInt
ushortFromBuff(String key, IBuffInfo buff) → int
ushortToBuff(int target, String key) → BuffUShort

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → BuffConverterBase
no setter